/* 
 * Copyright (C) 2004-2005 Jonathan Bindel
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Xml.Serialization;

using DCSharp.Backend.Managers;

namespace DCSharp.Backend.Objects
{
	public class FavoriteUserEventArgs : EventArgs
	{
		public FavoriteUserEventArgs(FavoriteUserInfo userInfo)
		{
			this.userInfo = userInfo;
		}
		
		public FavoriteUserInfo FavoriteUserInfo
		{
			get { return userInfo; }
		}
		private FavoriteUserInfo userInfo;
	}
	
	public class FavoriteUserInfo
	{
		public FavoriteUserInfo(Identity identity) : this()
		{
			this.nick = identity.Nick;
			this.cid = identity.Cid;
		}
		
		public FavoriteUserInfo(User user) : this()
		{
			this.nick = user.Nick;
			this.cid = user.Uid;
		}
		
		public FavoriteUserInfo()
		{
			lastSeen = DateTime.Now;
			autoGrant = true;
		}
		
		#region Properties
		
		[XmlAttribute]
		public string Nick
		{
			get { return nick; }
			set { nick = value; }
		}
		private string nick;
		
		[XmlAttribute("CID")]
		public string Cid
		{
			get { return cid; }
			set { cid = new Uid(value); }
		}
		private Uid cid;
		
		[XmlIgnore]
		public User User
		{
			get
			{
				if (user == null || user.Uid != cid)
				{
					user = User.Create(cid, nick);
				}
				return user;
			}
		}
		private User user;
		
		[XmlAttribute("UserDescription")]
		public string Description
		{
			get { return description; }
			set { description = value; }
		}
		private string description;
		
		[XmlAttribute]
		public DateTime LastSeen
		{
			get { return lastSeen; }
			set { lastSeen = value; }
		}
		private DateTime lastSeen;
		
		[XmlAttribute("GrantSlot")]
		public bool AutoGrant
		{
			get { return autoGrant; }
			set { autoGrant = value; }
		}
		private bool autoGrant;
		
		#endregion
	}
}
